Package: SpATS
Type: Package
Title: Spatial Analysis of Field Trials with Splines
Version: 1.0-20
Date: 2026-05-17
Authors@R: c(
	person("Maria Xose Rodriguez-Alvarez",
		email = "mxrodriguez@uvigo.es", role = c("aut", "cre")),
	person("Martin Boer", role = "aut"),
	person("Paul Eilers", role = "aut"),
	person("Fred van Eeuwijk", role = "ctb"))
Imports: stats, grDevices, graphics, fields, spam, data.table, methods
Description: Analysis of field trial experiments by modelling spatial trends using two-dimensional Penalised spline (P-spline) models.
License: GPL
NeedsCompilation: no
Packaged: 2026-05-17 09:41:15 UTC; mrodriguez
Author: Maria Xose Rodriguez-Alvarez [aut, cre],
  Martin Boer [aut],
  Paul Eilers [aut],
  Fred van Eeuwijk [ctb]
Maintainer: Maria Xose Rodriguez-Alvarez <mxrodriguez@uvigo.es>
Repository: CRAN
Date/Publication: 2026-05-17 13:50:02 UTC
Built: R 4.6.0; ; 2026-05-17 15:53:08 UTC; unix
