import(stats)
import(grDevices)
import(graphics)
import(spam)
import(data.table)
import(methods)
export(controlSpATS, plot.SpATS, plot.variogram.SpATS, obtain.spatialtrend, predict.SpATS, print.SpATS, PSANOVA, SpATS, summary.SpATS, variogram, variogram.SpATS, SAP, getHeritability)
S3method(variogram, SpATS)
S3method(print, SpATS)
S3method(print, summary.SpATS)
S3method(summary, SpATS)
S3method(plot, SpATS)
S3method(plot, variogram.SpATS)
S3method(predict, SpATS)
